@@ -41,6 +41,7 @@ fn get_stylesheets() -> Vec<String> {
         include_str!("../themes/components/checkbox.scss").to_string(),
         include_str!("../themes/components/avatar.scss").to_string(),
         include_str!("../themes/components/tag.scss").to_string(),
+        include_str!("../themes/components/popup.scss").to_string(),
     ]
 }
 
@@ -50,6 +51,7 @@ fn get_scripts() -> Vec<String> {
         include_str!("../js/menu.js").to_string(),
         include_str!("../js/popover.js").to_string(),
         include_str!("../js/table.js").to_string(),
+        include_str!("../js/popup.js").to_string(),
     ]
 }
 
