@@ -1,6 +1,6 @@
 use crate::node::{NodeContainer, NodeType};
 use crate::sp;
-use crate::components::Popover;
+use crate::components::{Popover, Popup};
 use uuid::Uuid;
 
 #[derive(Debug)]
@@ -115,6 +115,11 @@ pub trait DefaultModifiers<T = Self>: NodeContainer + Clone {
         self.clone()
     }
 
+    fn background(&mut self, value: &str) -> Self {
+        self.get_node().node_style.push(("background".to_string(), value.to_string()));
+        self.clone()
+    }
+
     fn border(&mut self, value: &str) -> Self {
         self.get_node().node_style.push(("border".to_string(), value.to_string()));
         self.clone()
@@ -184,6 +189,18 @@ pub trait DefaultModifiers<T = Self>: NodeContainer + Clone {
         self.get_node().node_style.push(("flex-grow".to_string(), value.to_string()));
         self.clone()
     }
+    fn line_height(&mut self, value: &str) -> Self {
+        self.get_node().node_style.push(("line-height".to_string(), value.to_string()));
+        self.clone()
+    }
+    fn border_radius(&mut self, value: &str) -> Self {
+        self.get_node().node_style.push(("border-radius".to_string(), value.to_string()));
+        self.clone()
+    }
+    fn text_align(&mut self, value: &str) -> Self {
+        self.get_node().node_style.push(("text-align".to_string(), value.to_string()));
+        self.clone()
+    }
     fn overflow(&mut self, overflow: Overflow) -> Self {
         self.get_node().node_style
             .push(("overflow".to_string(), format!("{:?}", overflow).to_lowercase()));
@@ -197,4 +214,13 @@ pub trait DefaultModifiers<T = Self>: NodeContainer + Clone {
         ));
         self.clone()
     }
+
+    fn popup(&mut self, popup: Popup) -> Self {
+        let id = Uuid::new_v4().to_hyphenated().to_string();
+        self.set_attr("id", id.as_str());
+        self.get_node().popup = Box::new(Some(
+            popup.clone().attach_to(id.as_str())
+        ));
+        self.clone()
+    }
 }
